==> jc-1.4.0.tar.gz: gnu/xml/libxmlj/dom/GnomeDocumentBuilderFactory.h <==
// public class gnu.xml.libxmlj.dom.GnomeDocumentBuilderFactory

// class file dependencies
// @dep_class e32e3618020562ee gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 2ac95ce8b4614a01 javax_xml_parsers_DocumentBuilderFactory

// header file dependencies
// @dep_header javax_xml_parsers_DocumentBuilderFactory

#include "javax/xml/parsers/DocumentBuilderFactory.h"

#ifndef _JC_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory_H_
#define _JC_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_javax_xml_parsers_DocumentBuilder$object;

// Typedefs
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$sub_refs	_jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$sub_refs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$sub_nonrefs	_jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$sub_nonrefs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$refs	_jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$refs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$nonrefs	_jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$nonrefs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$object	_jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$object;

typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$vmethods	_jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$vmethods;
typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$vtable	_jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$vtable;
typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$vtype	_jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$vtype;

// Constructors
extern void _jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$method$getAttribute$bd4ba72dbd34d711(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$object *, struct _jc_java_lang_String$object *);
extern struct _jc_javax_xml_parsers_DocumentBuilder$object *_jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$method$newDocumentBuilder$e5d58fd72aab1990(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$object *);
extern void _jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$method$setAttribute$f7af18cb25a05ce1(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Object$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$method_info$getAttribute$bd4ba72dbd34d711;
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$method_info$newDocumentBuilder$e5d58fd72aab1990;
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$method_info$setAttribute$f7af18cb25a05ce1;

// Virtual methods structure
struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$vmethods {
	struct _jc_java_lang_Object$object	*(*getAttribute$bd4ba72dbd34d711)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$object *, struct _jc_java_lang_String$object *);
	struct _jc_javax_xml_parsers_DocumentBuilder$object	*(*newDocumentBuilder$e5d58fd72aab1990)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$object *);
	void	(*setAttribute$f7af18cb25a05ce1)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Object$object *);
};

// Vtable
struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_xml_parsers_DocumentBuilderFactory$vmethods	javax_xml_parsers_DocumentBuilderFactory;
	_jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$vmethods	gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory;
};

// Vtype
struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$vtype {
	_jc_type			type;
	_jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$refs {
    _jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$sub_refs	gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory;
    _jc_javax_xml_parsers_DocumentBuilderFactory$sub_refs	javax_xml_parsers_DocumentBuilderFactory;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_xml_parsers_DocumentBuilderFactory$sub_nonrefs	javax_xml_parsers_DocumentBuilderFactory;
    _jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$sub_nonrefs	gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory;
};

// Object instance structure
struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$object {
	_jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$vtype	*vtype;
	_jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$vtype _jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$class_object;

#endif	/* _JC_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory_H_ */

==> jc-1.4.6.tar.gz: gnu/xml/libxmlj/dom/GnomeDocumentBuilderFactory.h <==
// public class gnu.xml.libxmlj.dom.GnomeDocumentBuilderFactory

// class file dependencies
// @dep_class e32e3618020562ee gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 2ac95ce8b4614a01 javax_xml_parsers_DocumentBuilderFactory

// header file dependencies
// @dep_header javax_xml_parsers_DocumentBuilderFactory

#include "javax/xml/parsers/DocumentBuilderFactory.h"

#ifndef _JC_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory_H_
#define _JC_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_javax_xml_parsers_DocumentBuilder$object;

// Typedefs
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$sub_refs	_jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$sub_refs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$sub_nonrefs	_jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$sub_nonrefs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$refs	_jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$refs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$nonrefs	_jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$nonrefs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$object	_jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$object;

typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$vmethods	_jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$vmethods;
typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$vtable	_jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$vtable;
typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$vtype	_jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$vtype;

// Constructors
extern void _jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$method$getAttribute$bd4ba72dbd34d711(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_javax_xml_parsers_DocumentBuilder$object *_jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$method$newDocumentBuilder$e5d58fd72aab1990(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$method$setAttribute$f7af18cb25a05ce1(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$method_info$getAttribute$bd4ba72dbd34d711;
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$method_info$newDocumentBuilder$e5d58fd72aab1990;
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$method_info$setAttribute$f7af18cb25a05ce1;

// Virtual methods structure
struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$vmethods {
	struct _jc_java_lang_Object$object	*(*getAttribute$bd4ba72dbd34d711)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	struct _jc_javax_xml_parsers_DocumentBuilder$object	*(*newDocumentBuilder$e5d58fd72aab1990)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$object *) _JC_JCNI_ATTR;
	void	(*setAttribute$f7af18cb25a05ce1)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_xml_parsers_DocumentBuilderFactory$vmethods	javax_xml_parsers_DocumentBuilderFactory;
	_jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$vmethods	gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory;
};

// Vtype
struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$vtype {
	_jc_type			type;
	_jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$refs {
    _jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$sub_refs	gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory;
    _jc_javax_xml_parsers_DocumentBuilderFactory$sub_refs	javax_xml_parsers_DocumentBuilderFactory;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_xml_parsers_DocumentBuilderFactory$sub_nonrefs	javax_xml_parsers_DocumentBuilderFactory;
    _jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$sub_nonrefs	gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory;
};

// Object instance structure
struct _jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$object {
	_jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$vtype	*vtype;
	_jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$vtype _jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory$class_object;

#endif	/* _JC_gnu_xml_libxmlj_dom_GnomeDocumentBuilderFactory_H_ */
